@@ -1,11 +1,22 @@
 // Install script for Enigmail
 
 var err;
-const APP_VERSION="0.94.3";
+const APP_VERSION="0.95.0.0";
+
+
+const ABI_PLATFORM_LINUX="Linux_x86-gcc3";
+const ABI_PLATFORM_WIN="WINNT_x86-msvc";
+const ABI_PLATFORM_DARWIN_PPC="Darwin_ppc-gcc3";
+const ABI_PLATFORM_DARWIN_X86="Darwin_x86-gcc3";
+
+const APP_PLATFORM_LINUX="linux";
+const APP_PLATFORM_WIN="win";
+const APP_PLATFORM_MAC="mac";
+const APP_PLATFORM_OTHER="other";
 
 err = initInstall("Enigmail v"+APP_VERSION,  // name for install UI
                   "/enigmail",               // registered name
-                  APP_VERSION+".0");         // package version
+                  APP_VERSION);              // package version
 
 logComment("initInstall: " + err);
 
@@ -24,7 +35,7 @@ if (!verifyDiskSpace(fProgram, srDest)) {
   var fDefaults   = getFolder("Program", "defaults/pref");
 
   // workaround for Mozilla 1.8a3 and newer, failing to register enigmime correctly
-  
+
   var delComps = [ "compreg.dat" ]; // Components registry
 
   for (var j=0; j<delComps.length; j++) {
@@ -33,11 +44,35 @@ if (!verifyDiskSpace(fProgram, srDest)) {
         File.remove(delFile);
   }
 
+  switch (getPlatform()) {
+  case APP_PLATFORM_LINUX:
+    addDirectory("", "platform/"+ABI_PLATFORM_LINUX+"/components",    fComponents, "");
+    break;
+  case APP_PLATFORM_WIN:
+    addDirectory("", "platform/"+ABI_PLATFORM_WIN+"/components",    fComponents, "");
+    break;
+  case APP_PLATFORM_MAC:
+    addDirectory("", "platform/"+ABI_PLATFORM_DARWIN_PPC+"/components",    fComponents, "");
+    addDirectory("", "platform/"+ABI_PLATFORM_DARWIN_X86+"/components",    fComponents, "");
+    break;
+  }
+
+  err = getLastError();
+  if (err == DOES_NOT_EXIST) {
+    // error code: file does not exist
+    logComment("platform dependent directory does not exist: " + err);
+    resetError();
+  }
+  else if (err != SUCCESS) {
+    cancelInstall(err);
+  }
+
   // addDirectory: blank, archive_dir, install_dir, install_subdir
   addDirectory("", "components",    fComponents, "");
   addDirectory("", "chrome",        fChrome,     "");
   addDirectory("", "defaults/pref", fDefaults,   "");
 
+
   err = getLastError();
   if (err == ACCESS_DENIED) {
     alert("Unable to write to components directory "+fComponents+".\n You will need to restart the browser with administrator/root privileges to install this software. After installing as root (or administrator), you will need to restart the browser one more time, as a privileged user, to register the installed software.\n After the second restart, you can go back to running the browser without privileges!");
@@ -51,15 +86,6 @@ if (!verifyDiskSpace(fProgram, srDest)) {
     // Register chrome
 
     var isTbird = false;
-    var execFile = 'thunderbird' + (getPlatform() == "win" ? '.exe' : '-bin');
-    if (File.exists(getFolder(getFolder('Program'), execFile))) {
-      isTbird = confirm("Detected installation on Thunderbird. Is this correct?");
-    }
-    else {
-      isTbird = false;
-    }
-//  old way:
-//  var isTbird = !confirm("Which Theme do you want to install for Enigmail? Click:\n[ OK ] for Mozilla\n[ Cancel ] for Thunderbird");
 
     registerChrome(PACKAGE | DELAYED_CHROME, getFolder("Chrome","enigmail.jar"), "content/enigmail/");
 
@@ -109,31 +135,19 @@ function verifyDiskSpace(dirPath, spaceRequired) {
 // which platform?
 function getPlatform() {
   var platformStr;
-  var platformNode;
+  var platformNode = "";
 
   if('platform' in Install) {
     platformStr = new String(Install.platform);
 
     if (!platformStr.search(/^Macintosh/))
-      platformNode = 'mac';
+      platformNode = APP_PLATFORM_MAC;
     else if (!platformStr.search(/^Win/))
-      platformNode = 'win';
+      platformNode = APP_PLATFORM_WIN;
+    else if (platformStr.search(/Linux/))
+      platformNode = APP_PLATFORM_LINUX;
     else
-      platformNode = 'unix';
-  }
-  else {
-    var fOSMac  = getFolder("Mac System");
-    var fOSWin  = getFolder("Win System");
-
-    logComment("fOSMac: "  + fOSMac);
-    logComment("fOSWin: "  + fOSWin);
-
-    if(fOSMac != null)
-      platformNode = 'mac';
-    else if(fOSWin != null)
-      platformNode = 'win';
-    else
-      platformNode = 'unix';
+      platformNode = APP_PLATFORM_OTHER;
   }
 
   return platformNode;
