@@ -5,6 +5,9 @@
 // the last configured Enigmail version
 pref("extensions.enigmail.configuredVersion","");
 
+// Hide prefs and menu entries from non-advanced users
+pref("extensions.enigmail.advancedUser",false);
+
 // additional parameter(s) to pass to GnuPG
 pref("extensions.enigmail.agentAdditionalParam","");
 
@@ -65,6 +68,9 @@ pref("extensions.enigmail.gpgVersionWarnCount",1);
 // enable 'Decrypt & open' for double click on attachment (if possible)
 pref("extensions.enigmail.handleDoubleClick",false);
 
+// headers to be retrieved from the mail backend, but hidden from the users
+pref("extensions.enigmail.hideHeaders", "x-enigmail-version openpgp content-transfer-encoding x-mimeole x-bugzilla-reason x-php-bug");
+
 // disable '<' and '>' around email addresses
 pref("extensions.enigmail.hushMailSupport",false);
 
@@ -87,13 +93,15 @@ pref("extensions.enigmail.logDirectory","");
 pref("extensions.enigmail.keepSettingsForReply",true);
 
 // list of keyservers to use
-pref("extensions.enigmail.keyserver","random.sks.keyserver.penguin.de, subkeys.pgp.net, pgp.mit.edu, ldap://certserver.pgp.com");
+pref("extensions.enigmail.keyserver","pool.sks-keyservers.net, subkeys.pgp.net, pgp.mit.edu, ldap://certserver.pgp.com");
 
 // keep passphrase for ... minutes
 pref("extensions.enigmail.maxIdleMinutes",5);
 
-// GnuPG hash algorithm (currently only 1 supported!)
-pref("extensions.enigmail.mimeHashAlgorithm",1);
+// GnuPG hash algorithm
+// 0: automatic seletion (i.e. let GnuPG choose)
+// 1: SHA1, 2: RIPEMD160, 3: SHA256, 4: SHA384, 5: SHA512
+pref("extensions.enigmail.mimeHashAlgorithm",0);
 
 // no passphrase for GnuPG key needed
 pref("extensions.enigmail.noPassphrase",false);
@@ -101,23 +109,26 @@ pref("extensions.enigmail.noPassphrase",false);
 // parse all mime headers (do NOT change)
 pref("extensions.enigmail.parseAllHeaders",true);
 
-// enable per recipient rules (0=off / 2=ask for every unknown user)
-pref("extensions.enigmail.perRecipientRules",1);
-
 // show quoted printable warning message (and remember selected state)
 pref("extensions.enigmail.quotedPrintableWarn",0);
 
 // use http proxy settings as set in Mozilla/Thunderbird
 pref("extensions.enigmail.respectHttpProxy",true);
 
-// enable selection of keys for unkown recipients (0=off, 1=when necessary, 2=always)
-pref("extensions.enigmail.recipientsSelectionOption",1);
+// selection of keys for unkown recipients
+// 1: rules only
+// 2: rules & email addresses (normal)
+// 3: email address only (no rules)
+// 4: manually (always prompt, no rules)
+// 5: no rules, no key selection
+pref("extensions.enigmail.recipientsSelection",2);
 
 // show "save draft encrypted" message (and remember selected state)
 pref("extensions.enigmail.saveEncrypted",0);
 
 // replacement of Mozilla's show all headers (because the original value is overriden)
-pref("extensions.enigmail.show_headers",1);
+// OBSOLETE
+// pref("extensions.enigmail.show_headers",1);
 
 // support different passwords for each key (not yet available)
 pref("extensions.enigmail.supportMultiPass",false);
@@ -132,7 +143,7 @@ pref("extensions.enigmail.encapsulatedMimeMaxSize", 8000);
 pref("extensions.enigmail.useGpgAgent",false);
 
 // use PGP/MIME (0=never, 1=allow, 2=always)
-pref("extensions.enigmail.usePGPMimeOption",1);
+// pref("extensions.enigmail.usePGPMimeOption",1); -- OBSOLETE, see mail.identity.default.pgpMimeMode
 
 // enable using gpgkeys_*
 pref("extensions.enigmail.useGpgKeysTool",true);
@@ -162,6 +173,7 @@ pref("mail.identity.default.pgpSignEncrypted", false);
 pref("mail.identity.default.defaultEncryptionPolicy", 0);
 pref("mail.identity.default.openPgpHeaderMode", 0);
 pref("mail.identity.default.openPgpUrlName", "");
+pref("mail.identity.default.pgpMimeMode", false);
 
 /*
    Other settings (change Mozilla behaviour)
