@@ -1,3 +1,4 @@
+#define MOZILLA_INTERNAL_API
 #include "mimedummy.h"
 #include "nsEnigMimeService.h"
 
@@ -16,7 +17,12 @@ static int MimeDummy_parse_buffer (char *, PRInt32, MimeObject *);
 // Mozilla >= 1.7
 static int MimeDummy_parse_buffer (const char *, PRInt32, MimeObject *);
 #endif
+#if MOZILLA_MAJOR_VERSION==1 && MOZILLA_MINOR_VERSION<9
 static int MimeDummy_parse_line (char *, PRInt32, MimeObject *);
+#else
+// Mozilla >= 1.9
+static int MimeDummy_parse_line (const char *, PRInt32, MimeObject *);
+#endif
 static int MimeDummy_parse_eof (MimeObject *, PRBool);
 static int MimeDummy_parse_end (MimeObject *, PRBool);
 static int MimeDummy_add_child (MimeObject *, MimeObject *);
@@ -114,7 +120,11 @@ MimeDummy_parse_buffer(char *buffer, PRInt32 size, MimeObject *obj)
 
 
 static int
+#if MOZILLA_MAJOR_VERSION==1 && MOZILLA_MINOR_VERSION<9
 MimeDummy_parse_line(char *line, PRInt32 length, MimeObject *obj)
+#else
+MimeDummy_parse_line(const char *line, PRInt32 length, MimeObject *obj)
+#endif
 {
   return 0;
 }
