@@ -38,7 +38,7 @@
 // The following define statement should occur before any include statements
 #define FORCE_PR_LOG       /* Allow logging even in release build */
 
-#define MOZILLA_INTERNAL_API
+#include "enigmail.h"
 #include "nspr.h"
 #include "nsCOMPtr.h"
 #include "nsString.h"
@@ -99,7 +99,7 @@ nsEnigMimeDecrypt::nsEnigMimeDecrypt()
 
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
+  rv = ENIG_GET_THREAD(myThread);
   DEBUG_LOG(("nsEnigMimeDecrypt:: <<<<<<<<< CTOR(%p): myThread=%p\n",
          this, myThread.get()));
 #endif
@@ -111,7 +111,7 @@ nsEnigMimeDecrypt::~nsEnigMimeDecrypt()
   nsresult rv;
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
+  rv = ENIG_GET_THREAD(myThread);
   DEBUG_LOG(("nsEnigMimeDecrypt:: >>>>>>>>> DTOR(%p): myThread=%p\n",
          this, myThread.get()));
 #endif
@@ -233,6 +233,8 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
 {
   // Enigmail stuff
   nsresult rv;
+  nsCOMPtr<nsIThread> myThread;
+  rv = ENIG_GET_THREAD(myThread);
 
   nsCAutoString uriSpec("");
 
@@ -306,7 +308,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
       nsCOMPtr<nsIEnigMimeHeaderSink> enigHeaderSink = do_QueryInterface(securityInfo);
       if (enigHeaderSink) {
         NS_NAMED_LITERAL_STRING(nullString, "");
-        rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, -1, 0, nullString.get(), nullString.get(), nullString.get(), errorMsg);
+        rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, -1, 0, nullString.get(), nullString.get(), nullString.get(), errorMsg, nullString.get());
       }
     }
 
@@ -345,12 +347,12 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
     if (NS_FAILED(rv)) return rv;
 
     if (!readCount) break;
-    
+
     if (iterations==1 && readCount > 25) {
       // add mime boundaries around text/plain message (bug 6627)
       if (nsCRT::strncasecmp("content-type:", buf, 13)==0) {
         PRUint32 whitespace=13;
-        while((whitespace<readCount) && buf[whitespace] && 
+        while((whitespace<readCount) && buf[whitespace] &&
               ((buf[whitespace]==' ') || (buf[whitespace]=='\t'))) { whitespace++; }
         if (buf[whitespace] && (whitespace<readCount)) {
           ctFound=nsCRT::strncasecmp(buf + whitespace, "text/plain", 10);
@@ -368,7 +370,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
             PR_SetError(status, 0);
             mOutputFun = NULL;
             mOutputClosure = NULL;
-      
+
             return NS_ERROR_FAILURE;
           }
           mOutputLen += strlen(header);
@@ -394,12 +396,12 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
     mOutputLen += readCount;
   }
 
-  
+
   if (ctFound==0) {
     // add mime boundaries around text/plain message (bug 6627)
     PR_SetError(0,0);
     strcpy(buf, "\n\n--enigDummy--\n");
-    
+
     int status = mOutputFun(buf, strlen(buf), mOutputClosure);
     if (status < 0) {
       PR_SetError(status, 0);
@@ -420,7 +422,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
       mOutputLen++;
     }
   }
-  
+
   PR_SetError(0,0);
 
   // Close input stream
@@ -434,6 +436,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
   nsXPIDLString keyId;
   nsXPIDLString userId;
   nsXPIDLString sigDate;
+  nsXPIDLString blockSeparation;
 
   PRUint32 uiFlags = nsIEnigmail::UI_PGP_MIME;
 
@@ -447,13 +450,14 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
                                       getter_Copies(userId),
                                       getter_Copies(sigDate),
                                       getter_Copies(errorMsg),
+                                      getter_Copies(blockSeparation),
                                       &exitCode);
   if (NS_FAILED(rv)) return rv;
 
   if (securityInfo) {
     nsCOMPtr<nsIEnigMimeHeaderSink> enigHeaderSink = do_QueryInterface(securityInfo);
     if (enigHeaderSink) {
-      rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, exitCode, statusFlags, keyId, userId, sigDate, errorMsg);
+      rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, exitCode, statusFlags, keyId, userId, sigDate, errorMsg, blockSeparation);
     }
   }
 
