@@ -66,6 +66,10 @@ window.addEventListener("unload", enigMessengerFinish,  false);
 function enigMessengerStartup() {
   DEBUG_LOG("enigmailMessengerOverlay.js: Startup\n");
 
+  gEnigMessagePane = document.getElementById("messagepane");
+
+  if (gEnigMessagePane == null) return; // TB 2.0 on Mac OS X calls this twice -- once far too early
+
   // enigUpdateOptionsDisplay();
 
   // Override SMIME ui
@@ -97,28 +101,17 @@ function enigMessengerStartup() {
   EnigOverrideAttribute( forwardEventElementIds, "oncommand",
                          "enigMsgForward('", "', event);");
 
-  // Override message headers view
-  var element = document.getElementById("viewallheaders");
-  if (element) {
-    var parentElement = element.parentNode;
-    if (parentElement) {
-      parentElement.setAttribute("onpopupshowing", "enigInitViewHeadersMenu();");
-    }
-  }
-
-  var viewElementIds = ["viewallheaders", "viewnormalheaders",
-                        "viewbriefheaders"];
-
-  EnigOverrideAttribute( viewElementIds, "oncommand",
-                         "enigMsgViewHeaders('", "');");
-
   enigOverrideLayoutChange();
 
-  EnigShowHeadersAll(true);
   gEnigSavedHeaders = null;
 
   gEnigDecryptButton = document.getElementById("button-enigmail-decrypt");
-  gEnigMessagePane = document.getElementById("messagepane");
+
+  var toolbarElem = document.getElementById("mail-bar2");
+  if (toolbarElem && EnigGetOS() == "Darwin") {
+    toolbarElem.setAttribute("platform", "macos");
+  }
+
   enigMessageFrameLoad();
 
   // Need to add event listener to gEnigMessagePane to make it work
@@ -129,10 +122,40 @@ function enigMessengerStartup() {
   if (EnigGetPref("handleDoubleClick")) {
     // ovveride function for double clicking an attachment
     EnigOverrideAttribute(["attachmentList"], "onclick",
-                         "enigAttachmentListClick('", "', event);");
+                        "enigAttachmentListClick('", "', event);");
   }
+
+  enigEnsureExtraHeaders();
 }
 
+function enigEnsureExtraHeaders() {
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigEnsureExtraHeaders\n");
+  var extraHdrs = " " + gEnigPrefRoot.getCharPref("mailnews.headers.extraExpandedHeaders").toLowerCase() + " ";
+
+  var extraHdrList = [
+    "x-enigmail-version",
+    "content-transfer-encoding",
+    "openpgp",
+// the following headers are added for compatibility with DispMUA extension:
+    "x-mimeole",
+    "x-bugzilla-reason",
+    "x-php-bug" ];
+
+  var addHdr = [];
+
+  for (hdr in extraHdrList) {
+    if (extraHdrs.indexOf(" "+extraHdrList[hdr]+" ") < 0) {
+      addHdr.push(extraHdrList[hdr]);
+    }
+  }
+
+  if (addHdr.length > 0) {
+    extraHdrs += addHdr.join(" ");
+    extraHdrs = extraHdrs.replace(/^ */, "").replace(/ *$/, "");
+    gEnigPrefRoot.setCharPref("mailnews.headers.extraExpandedHeaders", extraHdrs)
+  }
+
+}
 
 function enigMessengerFinish() {
   DEBUG_LOG("enigmailMessengerOverlay.js: Finish\n");
@@ -155,11 +178,8 @@ function enigViewSecurityInfo(event, displaySmimeMsg) {
 
         enigHandleUnknownKey();
 
-    } else if (gEnigSecurityInfo.statusFlags & ENIG_MULTIPLE_PARTS) {
-
-      enigDisplayMimeMessage();
-
-    } else if ( (gEnigSecurityInfo.statusFlags & nsIEnigmail.NODATA) &&
+    }
+    else if ( (gEnigSecurityInfo.statusFlags & nsIEnigmail.NODATA) &&
          (gEnigSecurityInfo.statusFlags &
            (nsIEnigmail.PGP_MIME_SIGNED | nsIEnigmail.PGP_MIME_ENCRYPTED)) ) {
 
@@ -171,7 +191,13 @@ function enigViewSecurityInfo(event, displaySmimeMsg) {
           EnigAlert(EnigGetString("reloadImapError"));
       }
 
-    } else {
+    }
+    else if ((gEnigSecurityInfo.statusFlags & (nsIEnigmail.PGP_MIME_SIGNED | nsIEnigmail.PGP_MIME_ENCRYPTED))
+            && gEnigSecurityInfo.blockSeparation && (gEnigSecurityInfo.blockSeparation.indexOf("0:")>=0)) {
+
+       enigDisplayMimeMessage();
+    }
+    else {
       EnigLongAlert(EnigGetString("securityInfo")+gEnigSecurityInfo.statusInfo);
     }
 
@@ -181,7 +207,7 @@ function enigViewSecurityInfo(event, displaySmimeMsg) {
       showMessageReadSecurityInfo();
     }
     else {
-      EnigAlert(EnigGetString("noPgpMessage"));
+      EnigAlert(EnigGetString("securityInfo")+gEnigSecurityInfo.statusInfo+"\n\n"+EnigGetString("noPgpMessage"));
     }
   }
 }
@@ -225,7 +251,7 @@ function enigDisplayMimeCallback(msgText) {
 
   plainText = enigmailSvc.decryptMessage(window, uiFlags, msgText,
                                 signatureObj, exitCodeObj, statusFlagsObj,
-                                keyIdObj, userIdObj, sigDetailsObj, errorMsgObj);
+                                keyIdObj, userIdObj, sigDetailsObj, errorMsgObj, blockSeparationObj);
 
   if (!plainText) {
      if (interactive && gEnigSecurityInfo && gEnigSecurityInfo.statusInfo)
@@ -233,71 +259,24 @@ function enigDisplayMimeCallback(msgText) {
      return;
   }
 
-  // hard-coded to avoid localization for security patch
-  plainText = "Warning: multiple OpenPGP message blocks detected" + "\n\n" + plainText + "\n\n" + "End of first OpenPGP block";
+  if (blockSeparationObj.value.indexOf(" ")>=0) {
+    var blocks = blockSeparationObj.value.split(/ /);
+    var blockInfo = blocks[0].split(/:/);
+    plainText = EnigGetString("notePartEncrypted") + "\n\n" + plainText.substr(0, blockInfo[1]) + "\n\n" + EnigGetString("noteCutMessage");
+  }
   EnigLongAlert(EnigGetString("securityInfo")+gEnigSecurityInfo.statusInfo+"\n---------------------------------\n"+plainText);
 }
 
-function enigInitViewHeadersMenu() {
-  DEBUG_LOG("enigmailMessengerOverlay.js: enigInitViewHeadersMenu\n");
-
-  var id;
-
-  var pref = 1;
-
-  if (EnigGetPref("parseAllHeaders")) {
-    pref = EnigGetPref("show_headers");
-
-  } else try {
-    pref = gEnigPrefRoot.getIntPref("mail.show_headers");
-  } catch (ex) {}
-
-  switch (pref) {
-  case 2:
-    id = "viewallheaders";
-    break;
-  case 1:
-  default:
-    id = "viewnormalheaders";
-    break;
-  }
-
-  var menuitem = document.getElementById(id);
-  if (menuitem)
-    menuitem.setAttribute("checked", "true");
-}
-
-function enigMsgViewHeaders(elementId) {
-  DEBUG_LOG("enigmailMessengerOverlay.js: enigMsgViewHeaders:"+elementId+"\n");
-
-  var value = gShowHeadersObj[elementId];
-  if (!value) value = 0;
-
-  EnigSetPref("show_headers", value);
-
-  if (!EnigGetPref("parseAllHeaders")) {
-    gEnigPrefRoot.setIntPref("mail.show_headers", value);
-  }
-
-  enigMessageReload(false);
-
-  return true;
-}
-
 function enigMessageReload(noShowReload) {
-  DEBUG_LOG("enigmailMessengerOverlay.js: MessageReload: "+noShowReload+"\n");
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigMessageReload: "+noShowReload+"\n");
 
   gEnigNoShowReload = noShowReload;
 
-  if (noShowReload) {
-    EnigShowHeadersAll(false);
-  }
-
   MsgReload();
 }
 
 function enigMessageCleanup() {
-  DEBUG_LOG("enigmailMessengerOverlay.js: MessageCleanup\n");
+  DEBUG_LOG("enigmailMessengerOverlay.js: enigMessageCleanup\n");
 
   var enigmailBox = document.getElementById("enigmailBox");
 
@@ -371,6 +350,7 @@ function enigMimeInit() {
 }
 
 function enigMessageFrameLoad() {
+  // called before a message is displayed
   DEBUG_LOG("enigmailMessengerOverlay.js: enigMessageFrameLoad\n");
   if (gEnigDecryptButton) {
     var setDisable=false;
@@ -392,15 +372,14 @@ function enigMessageFrameLoad() {
   }
 }
 
+
 function enigMessageFrameUnload() {
   DEBUG_LOG("enigmailMessengerOverlay.js: enigMessageFrameUnload\n");
 
   if (gEnigNoShowReload) {
-    EnigShowHeadersAll(false);
     gEnigNoShowReload = false;
 
   } else {
-    EnigShowHeadersAll(true);
     gEnigSavedHeaders = null;
 
     enigMessageCleanup();
@@ -536,57 +515,48 @@ function enigMessageDecrypt(event, isAuto) {
   if (EnigGetPref("parseAllHeaders")) {
     var showHeaders = 0;
 
-    try {
-      showHeaders = gEnigPrefRoot.getIntPref("mail.show_headers");
-    } catch (ex) {
+    // Copy selected headers
+    gEnigSavedHeaders = {};
+
+    for (var index=0; index < gEnigHeadersList.length; index++) {
+      var headerName = gEnigHeadersList[index];
+      var headerValue = "";
+
+      if (currentHeaderData[headerName]) {
+        headerValue = currentHeaderData[headerName].headerValue;
+      }
+
+      gEnigSavedHeaders[headerName] = headerValue;
+      DEBUG_LOG("enigmailMessengerOverlay.js: "+headerName+": "+headerValue+"\n");
     }
 
-    DEBUG_LOG("enigmailMessengerOverlay.js: mail.show_headers="+showHeaders+"\n");
-
-    if (showHeaders == 2) {
-      // Copy selected headers
-      gEnigSavedHeaders = {};
-
-      for (var index=0; index < gEnigHeadersList.length; index++) {
-        var headerName = gEnigHeadersList[index];
-        var headerValue = "";
-
-        if (currentHeaderData[headerName]) {
-          headerValue = currentHeaderData[headerName].headerValue;
-        }
-
-        gEnigSavedHeaders[headerName] = headerValue;
-        DEBUG_LOG("enigmailMessengerOverlay.js: "+headerName+": "+headerValue+"\n");
+    // var emailAttachment = false;
+    var embeddedSigned = null;
+    var embeddedEncrypted = null;
+    for (var indexb in currentAttachments) {
+      var attachment = currentAttachments[indexb];
+/* obsolete
+      if (attachment.contentType.search(/^message\/rfc822(;|$)/i) == 0) {
+        emailAttachment = true;
       }
-
-      var emailAttachment = false;
-      var embeddedSigned = null;
-      var embeddedEncrypted = null;
-      for (var indexb in currentAttachments) {
-        var attachment = currentAttachments[indexb];
-        if (attachment.contentType.search(/^message\/rfc822(;|$)/i) == 0) {
-          emailAttachment = true;
-        }
-        if (attachment.contentType.search(/^application\/pgp-signature/i) == 0) {
-          embeddedSigned = attachment.url.replace(/\.\d+\.\d+$/, "");
-        }
-        if (attachment.contentType.search(/^application\/pgp-encrypted/i) == 0) {
-          embeddedEncrypted = attachment.url.replace(/\.\d+\.\d+$/, "");
-        }
-        DEBUG_LOG("enigmailMessengerOverlay.js: "+indexb+": "+attachment.contentType+"\n");
-        //DEBUG_LOG("enigmailMessengerOverlay.js: "+indexb+": "+attachment.url+"\n");
+*/
+      if (attachment.contentType.search(/^application\/pgp-signature/i) == 0) {
+        embeddedSigned = attachment.url.replace(/\.\d+\.\d+$/, "");
       }
-
-      if (emailAttachment && (EnigGetPref("show_headers") != 2)) {
-        DEBUG_LOG("enigmailMessengerOverlay.js: Email attachment; reloading to hide headers\n");
-        enigMessageReload(true);
-        return;
+      if (attachment.contentType.search(/^application\/pgp-encrypted/i) == 0) {
+        embeddedEncrypted = attachment.url.replace(/\.\d+\.\d+$/, "");
       }
-
-    } else if (!gEnigSavedHeaders) {
-      ERROR_LOG("enigmailMessengerOverlay.js: enigMessageDecrypt: ERROR mail.show_headers="+showHeaders+" while parseAllHeaders is true\n");
+      DEBUG_LOG("enigmailMessengerOverlay.js: "+indexb+": "+attachment.contentType+"\n");
+      //DEBUG_LOG("enigmailMessengerOverlay.js: "+indexb+": "+attachment.url+"\n");
     }
 
+/* Obsolete
+    if (emailAttachment) {
+      // DEBUG_LOG("enigmailMessengerOverlay.js: Email attachment; reloading to hide headers\n");
+      enigMessageReload(true);
+      return;
+    }
+*/
   }
 
   var contentType = "";
@@ -618,8 +588,6 @@ function enigMessageDecrypt(event, isAuto) {
     return;
   }
 
-  EnigShowHeadersAll(false);
-
   if (((contentType.search(/^multipart\/encrypted(;|$)/i) == 0) ||
       (embeddedEncrypted && contentType.search(/^multipart\/mixed(;|$)/i) == 0))
        && (!embeddedSigned)) {
@@ -803,6 +771,7 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
     var statusFlagsObj = new Object();
     var userIdObj      = new Object();
     var sigDetailsObj  = new Object();
+    var blockSeparationObj = new Object();
 
     var signatureObj = new Object();
     signatureObj.value = signature;
@@ -814,7 +783,7 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
 
     plainText = enigmailSvc.decryptMessage(window, uiFlags, msgText,
                                  signatureObj, exitCodeObj, statusFlagsObj,
-                                 keyIdObj, userIdObj, sigDetailsObj, errorMsgObj);
+                                 keyIdObj, userIdObj, sigDetailsObj, errorMsgObj, blockSeparationObj);
 
     //DEBUG_LOG("enigmailMessengerOverlay.js: enigMessageParseCallback: plainText='"+plainText+"'\n");
 
@@ -838,7 +807,7 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
      return;
   }
 
-  enigUpdateHdrIcons(exitCode, statusFlags, keyIdObj.value, userIdObj.value, sigDetailsObj.value, errorMsg);
+  enigUpdateHdrIcons(exitCode, statusFlags, keyIdObj.value, userIdObj.value, sigDetailsObj.value, errorMsg, null);
 
   var noSecondTry = nsIEnigmail.GOOD_SIGNATURE |
         nsIEnigmail.EXPIRED_SIGNATURE |
@@ -869,6 +838,12 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
      return;
   }
 
+  if (blockSeparationObj.value.indexOf(" ")>=0) {
+    var blocks = blockSeparationObj.value.split(/ /);
+    var blockInfo = blocks[0].split(/:/);
+    plainText = EnigGetString("notePartEncrypted") + "\n\n" + plainText.substr(0, blockInfo[1]) + "\n\n" + EnigGetString("noteCutMessage");
+  }
+
   // Save decrypted message status, headers, and content
   var headerList = {"subject":"", "from":"", "date":"", "to":"", "cc":""};
 
@@ -1131,40 +1106,27 @@ function enigGetDecryptedMessage(contentType, includeHeaders) {
           var urlObj = new Object();
           msgService.GetUrlForUri(uriSpec, urlObj, msgWindow);
           var msgData, msgHdr
+
+          var msgDbHdr = messenger.msgHdrFromURI(uriSpec);
+          msgHdr = { "From": msgDbHdr.author,
+                     "Subject": msgDbHdr.subject,
+                     "To": msgDbHdr.recipients,
+                     "Cc": msgDbHdr.ccList,
+                     "Date": EnigGetDateTime(msgDbHdr.dateInSeconds, true, true) };
+
+
           if(urlObj.value.scheme=="news") {
             msgData = urlObj.value.QueryInterface(Components.interfaces.nsINntpUrl);
-            msgHdr = { "From":    msgData.messageHeader.author,
-                        "Subject": msgData.messageHeader.subject,
-                        "Cc":      msgData.messageHeader.ccList,
-                        "To":      msgData.messageHeader.recipients,
-                        "Date":    headerList.date,
-                        "Newsgroups": msgData.messageHeader.folder.name };
-          }
-          else if(urlObj.value.scheme=="imap") {
-            var msgKey=new Object();
-            msgData = urlObj.value.QueryInterface(Components.interfaces.nsIImapUrl);
-            // this only succeeds if exactly one message was selected, which is
-            // at this moment the case
-            msgData.createListOfMessageIdsString(msgKey);
-            var imapMsgHeader = msgData.imapMessageSink.GetMessageHeader(msgKey.value);
-            msgHdr = { "From":    imapMsgHeader.author,
-                        "Subject": imapMsgHeader.subject,
-                        "Cc":      imapMsgHeader.ccList,
-                        "To":      imapMsgHeader.recipients,
-                        "Date":    headerList.date };
-          }
-          else {
-            msgData = urlObj.value.QueryInterface(Components.interfaces.nsIMailboxUrl);
-            msgHdr = { "From":    msgData.messageHeader.author,
-                        "Subject": msgData.messageHeader.subject,
-                        "Cc":      msgData.messageHeader.ccList,
-                        "To":      msgData.messageHeader.recipients,
-                        "Date":    headerList.date };
+            if (typeof (currentHeaderData.newsgroups)) {
+              msgHdr.Newsgroups = currentHeaderData.newsgroups.headerValue;
+            }
           }
+
           for (headerName in msgHdr) {
-            if (msgHdr[headerName])
+            if (msgHdr[headerName] && msgHdr[headerName].length>0)
               contentData += headerName + ": " + msgHdr[headerName] + "\r\n";
           }
+
         }
       } catch (ex) {
         // the above seems to fail every now and then
@@ -1244,9 +1206,6 @@ function enigGetDecryptedMessage(contentType, includeHeaders) {
 function enigMsgForward(elementId, event) {
   DEBUG_LOG("enigmailMessengerOverlay.js: enigMsgForward: "+elementId+", "+event+"\n");
 
-  // Reset mail.show_headers pref to "original" value
-  EnigShowHeadersAll(false);
-
   if ((elementId == "cmd_forwardAttachment") ||
       (elementId == "threadPaneContext-forwardAsAttachment")) {
     MsgForwardAsAttachment(event);
@@ -1262,9 +1221,6 @@ function enigMsgForward(elementId, event) {
 function enigMsgDefaultPrint(elementId) {
   DEBUG_LOG("enigmailMessengerOverlay.js: enigMsgDefaultPrint: "+elementId+"\n");
 
-  // Reset mail.show_headers pref to "original" value
-  EnigShowHeadersAll(false);
-
   goDoCommand(elementId.indexOf("printpreview")>=0 ? "cmd_printpreview" : "cmd_print");
 }
 
@@ -1307,7 +1263,7 @@ function enigMsgPrint(elementId) {
   var messageList = [uri];
 
   if (gPrintSettings == null) {
-    gPrintSettings = GetPrintSettings();
+    gPrintSettings = PrintUtils.getPrintSettings();
   }
 
   var printPreview = (elementId.indexOf("printpreview")>=0);
