@@ -67,7 +67,7 @@ if (typeof(GenericSendMessage)=="function") {
     enigGenericSendMessage(msgType);
   }
 
-  
+
   window.addEventListener("load", enigMsgComposeStartup, false);
 
   // Handle recycled windows
@@ -319,7 +319,7 @@ function enigTogglePGPMime() {
 
 function enigAttachOwnKey() {
   DEBUG_LOG("enigmailMsgComposeOverlay.js: enigAttachOwnKey:\n");
-  
+
   var userIdValue;
   if (gEnigIdentity.getIntAttribute("pgpKeyMode")>0) {
     userIdValue = gEnigIdentity.getCharAttribute("pgpkeyId");
@@ -396,7 +396,7 @@ function enigExtractAndAttachKey(uid) {
 
   // add attachment to msg
   AddAttachment(keyAttachment);
-  
+
   if (typeof(ChangeAttachmentBucketVisibility) == "function") {
     // TB 1.1
     ChangeAttachmentBucketVisibility(false);
@@ -426,19 +426,32 @@ function enigUndoEncryption() {
     // undo inline encryption of attachments
     for (var i=0; i<gEnigModifiedAttach.length; i++) {
       var node = bucketList.firstChild;
+      var nodeNumber=-1;
       while (node) {
+        ++nodeNumber;
         if (node.attachment.url == gEnigModifiedAttach[i].newUrl) {
-          node.attachment.url = gEnigModifiedAttach[i].origUrl;
-          node.attachment.name = gEnigModifiedAttach[i].origName;
-          node.attachment.temporary = gEnigModifiedAttach[i].origTemp;
-          node.attachment.contentType = gEnigModifiedAttach[i].origCType;
+          if (gEnigModifiedAttach[i].encrypted) {
+            node.attachment.url = gEnigModifiedAttach[i].origUrl;
+            node.attachment.name = gEnigModifiedAttach[i].origName;
+            node.attachment.temporary = gEnigModifiedAttach[i].origTemp;
+            node.attachment.contentType = gEnigModifiedAttach[i].origCType;
+          }
+          else {
+            node = bucketList.removeItemAt(nodeNumber);
+            // Let's release the attachment object held by the node else it won't go away until the window is destroyed
+            node.attachment = null;
+          }
           // delete encrypted file
           try {
             gEnigModifiedAttach[i].newFile.remove(false);
           }
           catch (ex) {}
+
+          node = null; // next attachment please
+        }
+        else {
+          node=node.nextSibling;
         }
-        node=node.nextSibling;
       }
     }
 
@@ -684,25 +697,25 @@ function enigEncryptMsg(msgSendType) {
   var gotSendFlags = gEnigSendMode;
   var sendFlags=0;
   window.enigmailSendFlags=0;
-  
+
   var autoSaveAsDraft = nsIMsgCompDeliverMode.SaveAsDraft;
   try {
     // TB 1.5 only
     autoSaveAsDraft = nsIMsgCompDeliverMode.AutoSaveAsDraft;
   }
   catch (ex) {}
-  
+
   switch (msgSendType) {
-  case nsIMsgCompDeliverMode.Later:          
+  case nsIMsgCompDeliverMode.Later:
     sendFlags |= nsIEnigmail.SEND_LATER;
     break;
-  case nsIMsgCompDeliverMode.SaveAsDraft:   
+  case nsIMsgCompDeliverMode.SaveAsDraft:
   case nsIMsgCompDeliverMode.SaveAsTemplate:
   case autoSaveAsDraft:
     sendFlags |= nsIEnigmail.SAVE_MESSAGE;
     break;
   }
-    
+
   if (gotSendFlags & ENIG_SIGN)
       sendFlags |= ENIG_SIGN;
   if (gotSendFlags & ENIG_ENCRYPT) {
@@ -915,14 +928,14 @@ function enigEncryptMsg(msgSendType) {
           if (perRecipientRules>0 && gEnigEnableRules) {
             var matchedKeysObj = new Object;
             var flagsObj=new Object;
-            if (!getRecipientsKeys(toAddr, 
+            if (!getRecipientsKeys(toAddr,
                                   (repeatSelection==1),
-                                  matchedKeysObj, 
+                                  matchedKeysObj,
                                   flagsObj)) {
               window.cancelSendMessage=true;
               return;
             }
-           
+
             if (matchedKeysObj.value) toAddr=matchedKeysObj.value;
             if (flagsObj.value) {
               switch (flagsObj.sign) {
@@ -933,7 +946,7 @@ function enigEncryptMsg(msgSendType) {
                  sendFlags |= ENIG_SIGN;
                  break;
               }
-    
+
               switch (flagsObj.encrypt) {
                case 0:
                  sendFlags &= ~ENIG_ENCRYPT;
@@ -942,7 +955,7 @@ function enigEncryptMsg(msgSendType) {
                  sendFlags |= ENIG_ENCRYPT;
                  break;
               }
-    
+
               switch (flagsObj.pgpMime) {
                case 0:
                  sendFlags &= ~nsIEnigmail.SEND_PGP_MIME;
@@ -954,19 +967,19 @@ function enigEncryptMsg(msgSendType) {
             }
           }
           repeatSelection++;
-          
+
           if (sendFlags & ENIG_ENCRYPT) {
             // Encrypt test message for default encryption
             var testExitCodeObj    = new Object();
             var testStatusFlagsObj = new Object();
             var testErrorMsgObj    = new Object();
-  
+
             var testPlain = "Test Message";
             var testUiFlags   = nsIEnigmail.UI_TEST;
             var testSendFlags = nsIEnigmail.SEND_ENCRYPTED |
                                 nsIEnigmail.SEND_TEST |
                                 optSendFlags;
-  
+
             // test recipients
             testCipher = enigmailSvc.encryptMessage(window, testUiFlags,
                                                           testPlain,
@@ -975,8 +988,8 @@ function enigEncryptMsg(msgSendType) {
                                                           testExitCodeObj,
                                                           testStatusFlagsObj,
                                                           testErrorMsgObj);
-  
-  
+
+
             if ((recipientsSelectionOption==2) ||
                 ((testStatusFlagsObj.value & nsIEnigmail.INVALID_RECIPIENT) &&
                  (recipientsSelectionOption>0))) {
@@ -992,7 +1005,7 @@ function enigEncryptMsg(msgSendType) {
                 if (recipientsSelectionOption<2)
                   inputObj.options += ",noforcedisp";
                 inputObj.dialogHeader = EnigGetString("recipientsSelectionHdr");
-  
+
                 window.openDialog("chrome://enigmail/content/enigmailUserSelection.xul","", "dialog,modal,centerscreen", inputObj, resultObj);
                 try {
                   if (resultObj.cancelled) {
@@ -1045,7 +1058,7 @@ function enigEncryptMsg(msgSendType) {
        // always enable PGP/MIME if message is saved
        sendFlags |= nsIEnigmail.SEND_PGP_MIME;
      }
-     
+
      if ( hasAttachments &&
         (sendFlags & ENIG_ENCRYPT_OR_SIGN) &&
         !(sendFlags & nsIEnigmail.SEND_PGP_MIME) &&
@@ -1053,10 +1066,11 @@ function enigEncryptMsg(msgSendType) {
 
         inputObj = new Object();
         inputObj.pgpMimePossible = (usePGPMimeOption >= PGP_MIME_POSSIBLE);
-        inputObj.inlinePossible = (sendFlags & ENIG_ENCRYPT); // makes no sense for sign only!
+        // inputObj.inlinePossible = (sendFlags & ENIG_ENCRYPT); // makes no sense for sign only!
+        inputObj.inlinePossible = true;
         inputObj.restrictedScenario = false;
-        
-        // determine if attachments are all local (currently the only
+
+        // determine if attachments are all local files (currently the only
         // supported kind of attachments)
         var node = bucketList.firstChild;
         while (node) {
@@ -1069,7 +1083,7 @@ function enigEncryptMsg(msgSendType) {
         if (inputObj.pgpMimePossible || inputObj.inlinePossible) {
           resultObj = new Object();
           resultObj.selected = EnigGetPref("encryptAttachments");
-          
+
           //skip or not
           var skipCheck=EnigGetPref("encryptAttachmentsSkipDlg");
           if (skipCheck == 1) {
@@ -1158,7 +1172,7 @@ function enigEncryptMsg(msgSendType) {
      }
      else if (!gEnigProcessed && (sendFlags & ENIG_ENCRYPT_OR_SIGN)) {
        // use inline PGP
-       
+
        var sendInfo = {
          sendFlags: sendFlags,
          inlineEncAttach: inlineEncAttach,
@@ -1167,7 +1181,7 @@ function enigEncryptMsg(msgSendType) {
          uiFlags: uiFlags,
          bucketList: bucketList
        };
-       
+
        if (! enigEncryptInline(sendInfo)) {
          window.cancelSendMessage=true;
          return;
@@ -1178,20 +1192,18 @@ function enigEncryptMsg(msgSendType) {
      var isOffline = (gIOService && gIOService.offline);
      window.enigmailSendFlags=sendFlags;
 
-     
-     if (sendFlags & nsIEnigmail.SAVE_MESSAGE) {
-       // update the list of attachments
-       Attachments2CompFields(msgCompFields);
-     }
-     else if (EnigGetPref("confirmBeforeSend")) {
+     // update the list of attachments
+     Attachments2CompFields(msgCompFields);
+
+     if ((!(sendFlags & nsIEnigmail.SAVE_MESSAGE)) && EnigGetPref("confirmBeforeSend")) {
        if (!enigConfirmBeforeSend(toAddrList.join(", "), toAddr, sendFlags, isOffline)) {
          if (gEnigProcessed)
            enigUndoEncryption();
-           
+
          window.cancelSendMessage=true;
          return;
        }
-     } 
+     }
      else if ( (sendFlags & nsIEnigmail.SEND_WITH_CHECK) &&
                  !enigMessageSendCheck() ) {
        // Abort send
@@ -1203,9 +1215,8 @@ function enigEncryptMsg(msgSendType) {
      }
 
      if (usingPGPMime &&
-         ((sendFlags & ENIG_ENCRYPT_OR_SIGN) &&
-          (! (sendFlags & ENIG_ENCRYPT)))) {
-      // temporarily enable quoted-printable for PGP/MIME signed messages
+         ((sendFlags & ENIG_ENCRYPT_OR_SIGN))) {
+      // temporarily enable quoted-printable for PGP/MIME messages
        try {
           if (! gEnigPrefRoot.getBoolPref("mail.strictly_mime")) {
             gEnigPrefRoot.setBoolPref("mail.strictly_mime", true);
@@ -1244,7 +1255,7 @@ function enigEncryptInline(sendInfo) {
 
   var enigmailSvc = GetEnigmailSvc();
   if (! enigmailSvc) return false;
-  
+
   if (gMsgCompose.composeHTML) {
     var errMsg = EnigGetString("hasHTML");
     EnigAlertCount("composeHtmlAlertCount", errMsg);
@@ -1260,11 +1271,11 @@ function enigEncryptInline(sendInfo) {
   } catch (ex) {}
 
   try {
-  if (gEnigPrefRoot.getBoolPref("mail.strictly_mime")) {
-    if (EnigConfirmPref(EnigGetString("quotedPrintableWarn"), "quotedPrintableWarn")) {
-      gEnigPrefRoot.setBoolPref("mail.strictly_mime", false);
+    if (gEnigPrefRoot.getBoolPref("mail.strictly_mime")) {
+      if (EnigConfirmPref(EnigGetString("quotedPrintableWarn"), "quotedPrintableWarn")) {
+        gEnigPrefRoot.setBoolPref("mail.strictly_mime", false);
+      }
     }
-  }
   } catch (ex) {}
 
 
@@ -1320,7 +1331,7 @@ function enigEncryptInline(sendInfo) {
 
   if (origText.length > 0) {
     // Sign/encrypt body text
-    
+
     var escText = origText; // Copy plain text for possible escaping
 
     if (sendFlowed && !(sendInfo.sendFlags & ENIG_ENCRYPT)) {
@@ -1528,7 +1539,7 @@ function enigGenericSendMessage( msgType )
          }
 
         //Check if we have a subject, else ask user for confirmation
-        
+
         if (subject == "" && (! EnigGetPref("allowEmptySubject")))
         {
           if (gEnigPromptSvc)
@@ -1656,9 +1667,9 @@ function enigGenericSendMessage( msgType )
         msgType == nsIMsgCompDeliverMode.AutoSaveAsDraft ||
         msgType == nsIMsgCompDeliverMode.SaveAsTemplate)
       {
-        var fallbackCharset = new Object;
+        var fallbackCharset = "";
         if (gPromptService &&
-            !gMsgCompose.checkCharsetConversion(getCurrentIdentity(), fallbackCharset))
+            !enigCheckCharsetConversion(msgCompFields))
         {
           var dlgTitle = sComposeMsgsBundle.getString("initErrorDlogTitle");
           var dlgText = sComposeMsgsBundle.getString("12553");  // NS_ERROR_MSG_MULTILINGUAL_SEND
@@ -1672,7 +1683,7 @@ function enigGenericSendMessage( msgType )
           switch(result3)
           {
             case 0:
-              fallbackCharset.value = "UTF-8";
+              fallbackCharset = "UTF-8";
               break;
             case 1:  // send anyway
               msgCompFields.needToCheckCharset = false;
@@ -1681,9 +1692,8 @@ function enigGenericSendMessage( msgType )
               return;
           }
         }
-        if (fallbackCharset &&
-            fallbackCharset.value && fallbackCharset.value != "")
-          gMsgCompose.SetDocumentCharset(fallbackCharset.value);
+        if (fallbackCharset != "")
+          gMsgCompose.SetDocumentCharset(fallbackCharset);
       }
 
 
@@ -1754,6 +1764,31 @@ function enigGenericSendMessage( msgType )
 }
 
 
+// Replacement for buggy charset conversion detection of Thunderbird
+
+function enigCheckCharsetConversion(msgCompFields) {
+
+  if (msgCompFields.characterSet == "UTF-8") return true;
+
+  try {
+    var encoderFlags = EnigOutputFormatted | EnigOutputLFLineBreak;
+    var docText = EnigEditorGetContentsAs("text/plain", encoderFlags);
+
+    if (docText.length > 0) {
+      var converter = Components.classes[ENIG_SAVEASCHARSET_CONTRACTID].createInstance(Components.interfaces.nsISaveAsCharset);
+
+      converter.Init(msgCompFields.characterSet, 0, 1);
+
+      return (converter.Convert(docText).length >= docText.length);
+    }
+  }
+  catch (ex) {}
+
+  return true;
+}
+
+
+
 // encrypt attachments when sending inline PGP mails
 // It's quite a hack: the attachments are stored locally
 // and the attachments list is modified to pick up the
@@ -1845,24 +1880,42 @@ function enigEncryptAttachments(bucketList, newAttachments, window, uiFlags,
     var newUri = ioServ.newFileURI(newFile);
     fileInfo.newUrl  = newUri.asciiSpec;
     fileInfo.newFile = newFile;
+    fileInfo.encrypted = (sendFlags & ENIG_ENCRYPT);
 
     newAttachments.push(fileInfo);
     node = node.nextSibling;
   }
 
-  // if we got here, all attachments were encrpted successfully,
-  // so we replace their names & urls
-  node = bucketList.firstChild;
   var i=0;
-  while (node) {
-    node.attachment.url = newAttachments[i].newUrl;
-    node.attachment.name += EnigGetPref("inlineAttachExt");
-    node.attachment.contentType="application/octet-stream";
-    node.attachment.temporary=true;
+  if (sendFlags & ENIG_ENCRYPT) {
+    // if we got here, all attachments were encrpted successfully,
+    // so we replace their names & urls
+    node = bucketList.firstChild;
 
-    ++i; node = node.nextSibling;
+    while (node) {
+      node.attachment.url = newAttachments[i].newUrl;
+      node.attachment.name += EnigGetPref("inlineAttachExt");
+      node.attachment.contentType="application/octet-stream";
+      node.attachment.temporary=true;
+
+      ++i; node = node.nextSibling;
+    }
   }
+  else {
+    // for inline signing we need to add new attachments for every
+    // signed file
+    for (i=0; i<newAttachments.length; i++) {
+      // create new attachment
+      var fileAttachment = Components.classes["@mozilla.org/messengercompose/attachment;1"].createInstance(Components.interfaces.nsIMsgAttachment);
+      fileAttachment.temporary = true;
+      fileAttachment.url = newAttachments[i].newUrl;
+      fileAttachment.name = newAttachments[i].origName + EnigGetPref("inlineSigAttachExt");
 
+      // add attachment to msg
+      AddAttachment(fileAttachment);
+    }
+
+  }
   return 0;
 
 }
@@ -1932,13 +1985,19 @@ function enigDecryptQuote(interactive) {
   var tail = docText.substr(endIndex+1);
 
   var pgpBlock = docText.substr(beginIndex, endIndex-beginIndex+1);
+  var indentRegexp;
 
   if (indentStr) {
     // MULTILINE MATCHING ON
     RegExp.multiline = true;
 
+    if (indentStr == "> ") {
+      // replace ">> " with "> > " to allow correct quoting
+      pgpBlock = pgpBlock.replace(/^>>/g, "> >");
+    }
+
     // Delete indentation
-    var indentRegexp = new RegExp("^"+indentStr, "g");
+    indentRegexp = new RegExp("^"+indentStr, "g");
 
     pgpBlock = pgpBlock.replace(indentRegexp, "");
     tail     =     tail.replace(indentRegexp, "");
@@ -1974,7 +2033,7 @@ function enigDecryptQuote(interactive) {
 
   // Encode ciphertext from unicode to charset
   var cipherText = EnigConvertFromUnicode(pgpBlock, charset);
-  
+
   if ((! gEnigPrefRoot.getBoolPref("mailnews.reply_in_default_charset")) && (blockType == "MESSAGE")) {
     // set charset according to PGP block, if available (encrypted messages only)
     cipherText = cipherText.replace(/\r\n/g, "\n");
@@ -1988,7 +2047,7 @@ function enigDecryptQuote(interactive) {
       }
     }
   }
-  
+
   // Decrypt message
   var signatureObj   = new Object();
   signatureObj.value = "";
@@ -2033,6 +2092,10 @@ function enigDecryptQuote(interactive) {
     }
   }
 
+  if (blockType == "MESSAGE" && exitCode == 0 && plainText.length==0) {
+    plainText = " ";
+  }
+
   if (!plainText) {
     if (blockType != "SIGNED MESSAGE")
       return;
@@ -2043,17 +2106,21 @@ function enigDecryptQuote(interactive) {
   }
 
   var doubleDashSeparator = EnigGetPref("doubleDashSeparator")
-  if (gMsgCompose.type != nsIMsgCompType.Template && 
+  if (gMsgCompose.type != nsIMsgCompType.Template &&
       gMsgCompose.type != nsIMsgCompType.Draft &&
       doubleDashSeparator) {
     var signOffset = plainText.search(/[\r\n]-- +[\r\n]/);
 
+    if (signOffset < 0 && blockType == "SIGNED MESSAGE") {
+      signOffset = plainText.search(/[\r\n]--[\r\n]/);
+    }
+
     if (signOffset > 0) {
       // Strip signature portion of quoted message
       plainText = plainText.substr(0, signOffset+1);
     }
   }
-  
+
   var clipBoard = Components.classes[ENIG_CLIPBOARD_CONTRACTID].getService(Components.interfaces.nsIClipboard);
   if (clipBoard.supportsSelectionClipboard()) {
     // get the clipboard contents for selected text (X11)
@@ -2068,7 +2135,7 @@ function enigDecryptQuote(interactive) {
     }
     catch(ex) {}
   }
-  
+
   // Replace encrypted quote with decrypted quote (destroys selection clipboard on X11)
   EnigEditorSelectAll();
 
@@ -2088,7 +2155,7 @@ function enigDecryptQuote(interactive) {
 
   if (tail)
     EnigEditorInsertText(tail);
-    
+
   if (clipBoard.supportsSelectionClipboard()) {
     try {
       // restore the clipboard contents for selected text (X11)
@@ -2204,42 +2271,50 @@ function EnigEditorInsertAsQuotation(plainText) {
 
     DEBUG_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: mailEditor="+mailEditor+"\n");
 
-    // use pasteAsQuotation because inertAsQuotation is buggy with TB 1.5
-    var clipBoard = Components.classes[ENIG_CLIPBOARD_CONTRACTID].getService(Components.interfaces.nsIClipboard);
-    // get the clipboard content
-    var transferable = Components.classes[ENIG_TRANSFERABLE_CONTRACTID].createInstance(Components.interfaces.nsITransferable);
-    var xferTypes = [ "text/unicode", "text/html" ];
+    var appInfo = Components.classes["@mozilla.org/xre/app-info;1"].getService(Components.interfaces.nsIXULAppInfo);
+    var vc = Components.classes["@mozilla.org/xpcom/version-comparator;1"].getService(Components.interfaces.nsIVersionComparator);
 
-    for (var i=0; i < xferTypes.length; i++) {
-      transferable.addDataFlavor(xferTypes[i]);
+    if (vc.compare("1.8.0.2", appInfo.platformVersion) <= 0) {
+      // TB 1.5.0.2 and newer
+      mailEditor.insertAsQuotation(plainText);
     }
-    var flavour = {};
-    var data = {};
-    var length = {};
-    try {
-      clipBoard.getData(transferable, clipBoard.kGlobalClipboard);
-      transferable.getAnyTransferData(flavour, data, length);
+    else {
+      // use pasteAsQuotation because inertAsQuotation is buggy with TB 1.5.0.0
+      var clipBoard = Components.classes[ENIG_CLIPBOARD_CONTRACTID].getService(Components.interfaces.nsIClipboard);
+      // get the clipboard content
+      var transferable = Components.classes[ENIG_TRANSFERABLE_CONTRACTID].createInstance(Components.interfaces.nsITransferable);
+      var xferTypes = [ "text/unicode", "text/html" ];
+
+      for (var i=0; i < xferTypes.length; i++) {
+        transferable.addDataFlavor(xferTypes[i]);
+      }
+      var flavour = {};
+      var data = {};
+      var length = {};
+      try {
+        clipBoard.getData(transferable, clipBoard.kGlobalClipboard);
+        transferable.getAnyTransferData(flavour, data, length);
+      }
+      catch (ex) {
+        ERROR_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: getting clipboard failed\n");
+      }
+
+      try {
+        var pasteClipboard;
+
+        // paste the email text
+        pasteClipboard = Components.classes[ENIG_CLIPBOARD_HELPER_CONTRACTID].getService(Components.interfaces.nsIClipboardHelper);
+        pasteClipboard.copyStringToClipboard(plainText, clipBoard.kGlobalClipboard);
+        mailEditor.pasteAsQuotation(clipBoard.kGlobalClipboard);
+
+        data = data.value.QueryInterface(Components.interfaces.nsISupportsString).data;
+        pasteClipboard.copyStringToClipboard(data, clipBoard.kGlobalClipboard);
+      }
+      catch (ex) {
+        ERROR_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: (re-)setting clipboard failed\n");
+      }
     }
-   catch (ex) {
-      ERROR_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: getting clipboard failed\n");
-   }
-
-    try {
-      var pasteClipboard;
-
-      // paste the email text
-      pasteClipboard = Components.classes[ENIG_CLIPBOARD_HELPER_CONTRACTID].getService(Components.interfaces.nsIClipboardHelper);
-      pasteClipboard.copyStringToClipboard(plainText, clipBoard.kGlobalClipboard);
-      mailEditor.pasteAsQuotation(clipBoard.kGlobalClipboard);
-
-      data = data.value.QueryInterface(Components.interfaces.nsISupportsString).data;
-      pasteClipboard.copyStringToClipboard(data, clipBoard.kGlobalClipboard);
-   }
-   catch (ex) {
-      ERROR_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: (re-)setting clipboard failed\n");
-   }
-
-   return 1;
+    return 1;
   }
   return 0;
 }
