@@ -75,19 +75,19 @@ function enigStartHeaders()
 
     if (statusText) statusText.value="";
   }
-  
+
   if (statusText)
     statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
 
   if (statusTextBox)
     statusTextBox.setAttribute("class", "enigmailHeaderNameBox enigmailHeaderBoxLabelSignatureOk");
-    
+
   statusText = document.getElementById("collapsedEnigmailStatusText");
 
   if (enigmailBox && !enigmailBox.collapsed) {
     if (statusText) tatusText.value="";
   }
-  
+
   if (statusText)
     statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
 
@@ -119,7 +119,7 @@ function enigEndHeaders()
   if (statusText) {
     statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
   }
-  
+
   statusText = document.getElementById("collapsedEnigmailStatusText");
   if (statusText) {
     statusText.setAttribute("class", "plain enigmailHeaderValue enigmailHeaderBoxLabelSignatureOk");
@@ -137,7 +137,7 @@ function enigMatchUidToSender(userId) {
     fromAddr=EnigStripEmail(fromAddr);
   }
   catch(ex) {}
-  
+
   var userIdList=userId.split(/\n/);
   try {
     for (var i=0; i<userIdList.length; i++) {
@@ -184,7 +184,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
       fullStatusInfo=errorMsg;
     }
   }
-  
+
 
   if (errorLines && (errorLines.length > 22) ) {
     // Retain only first twenty lines and last two lines of error message
@@ -235,7 +235,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
   if (msgSigned && (statusFlags & nsIEnigmail.IMPORTED_KEY)) {
     statusFlags &= (~nsIEnigmail.IMPORTED_KEY);
   }
-  
+
   if (((!(statusFlags & (nsIEnigmail.DECRYPTION_INCOMPLETE |
             nsIEnigmail.DECRYPTION_FAILED |
             nsIEnigmail.UNVERIFIED_SIGNATURE |
@@ -246,7 +246,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     // Normal exit / display message
     statusLine = errorMsg;
     statusInfo = statusLine;
-    
+
     if (sigDetails) {
       var detailArr=sigDetails.split(/ /);
 
@@ -254,7 +254,13 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
       var txt = EnigGetString("keyAndSigDate", keyId.substr(-8, 8), dateTime);
       statusArr.push(txt);
       statusInfo += "\n" + txt;
-      var fpr = EnigFormatFpr(detailArr[0]);
+      var fpr = "";
+      if (detailArr.length >= 10) {
+        fpr = EnigFormatFpr(detailArr[9]);
+      }
+      else {
+        EnigFormatFpr(detailArr[0]);
+      }
       if (fpr) {
         statusInfo += "\n"+EnigGetString("keyFpr", fpr);
       }
@@ -264,22 +270,22 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
   } else {
     if (keyId) {
       statusInfo = EnigGetString("keyNeeded",keyId);
-  
+
       if (statusFlags & nsIEnigmail.INLINE_KEY) {
         statusLine = statusInfo + EnigGetString("clickDecrypt");
       } else {
         statusLine = statusInfo + EnigGetString("clickPen");
       }
-  
+
       statusInfo = EnigGetString("unverifiedSig");
       statusLine = statusInfo + EnigGetString("clickPen");
       statusInfo += "\n\n" + errorMsg;
-  
+
     } else if (statusFlags & nsIEnigmail.UNVERIFIED_SIGNATURE) {
       statusInfo = EnigGetString("unverifiedSig");
       statusLine = statusInfo + EnigGetString("clickQueryPenDetails");
       statusInfo += "\n\n" + errorMsg;
-      
+
     } else if (statusFlags & (nsIEnigmail.BAD_SIGNATURE |
                               nsIEnigmail.UNVERIFIED_SIGNATURE |
                               nsIEnigmail.EXPIRED_SIGNATURE |
@@ -287,32 +293,32 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
       statusInfo = EnigGetString("failedSig");
       statusLine = statusInfo + EnigGetString("clickPenDetails");
       statusInfo += "\n\n" + errorMsg;
-  
+
     } else if (statusFlags & nsIEnigmail.DECRYPTION_INCOMPLETE) {
       statusInfo = EnigGetString("incompleteDecrypt");
       statusLine = statusInfo + EnigGetString("clickKey");
       statusInfo += "\n\n" + errorMsg;
-  
+
     } else if (statusFlags & nsIEnigmail.DECRYPTION_FAILED) {
       if (statusFlags & nsIEnigmail.NO_SECKEY) {
         statusInfo = EnigGetString("needKey");
       } else {
         statusInfo = EnigGetString("failedDecrypt");
       }
-  
+
       statusLine = statusInfo + EnigGetString("clickKeyDetails");
       statusInfo += "\n\n" + errorMsg;
-  
+
     } else if (statusFlags & nsIEnigmail.BAD_PASSPHRASE) {
       statusInfo = EnigGetString("badPhrase");
       statusLine = statusInfo + EnigGetString("clickDecryptRetry");
       statusInfo += "\n\n" + errorMsg;
-  
+
     } else if (statusFlags & nsIEnigmail.IMPORTED_KEY) {
       statusLine = "";
       statusInfo = "";
       EnigAlert(errorMsg);
-  
+
     } else {
       statusInfo = EnigGetString("failedDecryptVerify");
       statusLine = statusInfo + EnigGetString("viewInfo");
@@ -352,7 +358,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
       }
     }
   }
-  
+
   gEnigSecurityInfo = { statusFlags: statusFlags,
                         keyId: keyId,
                         userId: userId,
@@ -385,7 +391,7 @@ function enigUpdateHdrIcons(exitCode, statusFlags, keyId, userId, sigDetails, er
     enigmailBox.setAttribute("collapsed", "true");
     enigDisplayExtendedStatus(false);
   }
-  
+
   if (!gSMIMEContainer)
     return;
 
@@ -478,7 +484,7 @@ function enigDispSecurityContext() {
       menuElement.setAttribute("disabled", "true");
     }
   }
-  
+
   enigSetSenderStatus("signSenderKey", "editSenderKeyTrust" , "showPhoto");
 }
 
@@ -497,7 +503,7 @@ function enigSetSenderStatus(elemSign, elemTrust, elemPhoto) {
       photo=true;
     }
     if (gEnigSecurityInfo.msgSigned ) {
-      if (!(gEnigSecurityInfo.statusFlags & 
+      if (!(gEnigSecurityInfo.statusFlags &
            (nsIEnigmail.REVOKED_KEY | nsIEnigmail.EXPIRED_KEY_SIGNATURE | nsIEnigmail.UNVERIFIED_SIGNATURE))) {
         sign=true;
       }
@@ -513,7 +519,7 @@ function enigSetSenderStatus(elemSign, elemTrust, elemPhoto) {
     document.getElementById("enigmail_"+elemSign).setAttribute("disabled", !sign);
   if (elemPhoto)
     document.getElementById("enigmail_"+elemPhoto).setAttribute("disabled", !photo);
-  
+
 }
 
 function enigEditKeyTrust() {
@@ -623,7 +629,7 @@ function enigToggleHeaderView() {
   var viewToggle = document.getElementById("enigToggleHeaderView");
   var expandedText = document.getElementById("expandedEnigmailStatusText");
   var state = viewToggle.getAttribute("state");
-  
+
   if (state=="true") {
     viewToggle.setAttribute("state", "false");
     viewToggle.setAttribute("class", "collapsedHeaderViewButton");
@@ -638,6 +644,77 @@ function enigToggleHeaderView() {
   }
 }
 
+function enigOnShowAttachmentContextMenu() {
+  DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigOnShowAttachmentContextMenu\n");
+  // first, call the original function ...
+  onShowAttachmentContextMenu();
+
+  // then, do our own additional stuff ...
+  var attachmentList = document.getElementById('attachmentList');
+  var selectedAttachments = attachmentList.selectedItems;
+  var decryptOpenMenu = document.getElementById('enigmail_ctxDecryptOpen');
+  var decryptSaveMenu = document.getElementById('enigmail_ctxDecryptSave');
+  var importMenu = document.getElementById('enigmail_ctxImportKey');
+
+  if (selectedAttachments.length > 0)
+  {
+    if (selectedAttachments[0].attachment.contentType.search(/^application\/pgp-keys/i) == 0) {
+      importMenu.removeAttribute('disabled');
+      decryptOpenMenu.setAttribute('disabled', true);
+      decryptSaveMenu.setAttribute('disabled', true);
+    }
+    else if (enigCheckEncryptedAttach(selectedAttachments[0].attachment)) {
+      importMenu.setAttribute('disabled', true);
+      decryptOpenMenu.removeAttribute('disabled');
+      decryptSaveMenu.removeAttribute('disabled');
+      if (! selectedAttachments[0].attachment.displayName) {
+        selectedAttachments[0].attachment.displayName="message.pgp"
+      }
+    }
+    else {
+      importMenu.setAttribute('disabled', true);
+      decryptOpenMenu.setAttribute('disabled', true);
+      decryptSaveMenu.setAttribute('disabled', true);
+    }
+  }
+  else
+  {
+    openMenu.setAttribute('disabled', true);
+    saveMenu.setAttribute('disabled', true);
+    decryptOpenMenu.setAttribute('disabled', true);
+    decryptSaveMenu.setAttribute('disabled', true);
+    importMenu.setAttribute('disabled', true);
+  }
+}
+
+function enigCanDetachAttachments() {
+  DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigCanDetachAttachments\n");
+  var canDetach = true;
+  if (gEnigSecurityInfo && (typeof(gEnigSecurityInfo.statusFlags) != "undefined")) {
+    canDetach = ((gEnigSecurityInfo.statusFlags &
+                 (nsIEnigmail.PGP_MIME_SIGNED | nsIEnigmail.PGP_MIME_ENCRYPTED)) ? false : true);
+  }
+  return canDetach;
+}
+
+function enigFillAttachmentListPopup(item) {
+  DEBUG_LOG("enigmailMsgHdrViewOverlay.js: enigFillAttachmentListPopup\n");
+  FillAttachmentListPopup(item);
+
+  if (! enigCanDetachAttachments()) {
+    for (var i=0; i< item.childNodes.length; i++) {
+      if (item.childNodes[i].className == "menu-iconic") {
+        var mnu = item.childNodes[i].firstChild.firstChild;
+        while (mnu) {
+          if (mnu.getAttribute("oncommand").search(/(detachAttachment|deleteAttachment)/) >=0) {
+            mnu.setAttribute("disabled" , true);
+          }
+          mnu = mnu.nextSibling;
+        }
+      }
+    }
+  }
+}
 
 addEventListener('messagepane-loaded', enigMsgHdrViewLoad, true);
 addEventListener('messagepane-hide', enigMsgHdrViewHide, true);
@@ -645,6 +722,19 @@ addEventListener('messagepane-unhide', enigMsgHdrViewUnhide, true);
 
 // THE FOLLOWING OVERRIDES CODE IN msgHdrViewOverlay.js
 
+function CanDetachAttachments()
+{
+  var uri = GetLoadedMessage();
+  var canDetach = !IsNewsMessage(uri) && (!IsImapMessage(uri) || CheckOnline());
+  if (canDetach && ("content-type" in currentHeaderData))
+  {
+    var contentType = currentHeaderData["content-type"].headerValue;
+    canDetach = contentType.indexOf("application/x-pkcs7-mime") < 0 &&
+        contentType.indexOf("application/x-pkcs7-signature") < 0;
+  }
+  return canDetach && enigCanDetachAttachments();
+}
+
 
 // for Mozilla >= 1.6a only
 if (createNewAttachmentInfo.prototype.openAttachment) {
@@ -670,16 +760,18 @@ if (messageHeaderSink) {
     DEBUG_LOG("enigmailMsgHdrViewOverlay.js: messageHeaderSink.onStartHeaders: START\n");
 
     mSaveHdr = null;
-    
-    // clear out any pending collected address timers...
-    if (gCollectAddressTimer)
-    {
-      gCollectAddess = "";
-      clearTimeout(gCollectAddressTimer);
-      gCollectAddressTimer = null;
+
+    if (typeof(gCollectAddressTimer)!="undefined") {
+      // clear out any pending collected address timers...
+      if (gCollectAddressTimer)
+      {
+        gCollectAddess = "";
+        clearTimeout(gCollectAddressTimer);
+        gCollectAddressTimer = null;
+      }
     }
     mSaveHdr = null;
-    
+
     if (this.enigDetermineHeadersPref())
     {
       gViewAllHeaders = true;
@@ -703,7 +795,7 @@ if (messageHeaderSink) {
     gBuildAttachmentPopupForCurrentMsg = true;
     ClearAttachmentList();
     ClearEditMessageButton();
-    
+
     if (typeof(gMessageNotificationBar) == "object") {
       // TB >= 1.0+
       gMessageNotificationBar.clearMsgNotifications();
