@@ -36,7 +36,6 @@ GPL.
 // Initialize enigmailCommon
 EnigInitCommon("pref-enigmail");
 
-var gMimeHashElement, gSendFlowedElement, gSendFlowedValue;
 var gMimePartsElement, gMimePartsValue;
 
 function prefOnLoad() {
@@ -48,53 +47,33 @@ function prefOnLoad() {
           // hide basic tab
           document.getElementById("basic").setAttribute("collapsed", true);
           document.getElementById("basicTab").setAttribute("collapsed", true);
-          var sendTab=document.getElementById("sendTab");
-          sendTab.click();
-          sendTab.setAttribute("selected", true);
+          selectPrefTabPanel("sendTab");
+      }
+      else {
+        EnigCollapseAdvanced(document.getElementById("prefTabBox"), "hidden", null);
+        EnigCollapseAdvanced(document.getElementById("enigPrefTabPanel"), "hidden", null);
+
       }
 
-
       if ((typeof window.arguments[0].selectTab)=="string") {
-          var selectTab=document.getElementById(window.arguments[0].selectTab);
-          selectTab.click();
-          selectTab.setAttribute("selected", true);
+          selectPrefTabPanel(window.arguments[0].selectTab);
+          prefTabs.selectedTab = selectTab;
       }
 
    }
-   
+
    if ((! window.arguments) || (window.arguments[0].clientType!="seamonkey")) {
       document.getElementById("enigmail_disableSMIMEui").setAttribute("collapsed", true);
       var uninst = document.getElementById("uninstall");
       if (uninst) uninst.setAttribute("collapsed", "true");
-   }
-   
-   EnigDisplayRadioPref("usePGPMimeOption", EnigGetPref("usePGPMimeOption"),
-                        gUsePGPMimeOptionList);
+      EnigCollapseAdvanced(document.getElementById("prefTabBox"), "hidden", null);
+      EnigCollapseAdvanced(document.getElementById("enigPrefTabPanel"), "hidden", null);
 
-
-   EnigDisplayRadioPref("recipientsSelectionOption", EnigGetPref("recipientsSelectionOption"),
-                        gEnigRecipientsSelectionOptions);
-
-   EnigDisplayRadioPref("perRecipientRules", EnigGetPref("perRecipientRules"),
-                        gEnigPerRecipientRules);
-
-   gMimeHashElement = document.getElementById("mimeHashList");
-   gMimeHashElement.selectedIndex = EnigGetPref("mimeHashAlgorithm")-1;
-
-   gSendFlowedElement = document.getElementById("send_plaintext_flowed");
-
-   try {
-     gSendFlowedValue = gEnigPrefRoot.getBoolPref("mailnews.send_plaintext_flowed");
-   } catch (ex) {
-     gSendFlowedValue = true;
    }
 
-   if (gSendFlowedValue) {
-     gSendFlowedElement.setAttribute("checked", "true");
-   } else {
-     gSendFlowedElement.removeAttribute("checked");
-   }
-   
+   EnigDisplayRadioPref("recipientsSelection", EnigGetPref("recipientsSelection"),
+                        gEnigRecipientsSelection);
+
    gMimePartsElement = document.getElementById("mime_parts_on_demand");
 
    try {
@@ -109,14 +88,51 @@ function prefOnLoad() {
      gMimePartsElement.removeAttribute("checked");
    }
 
+   var overrideGpg = document.getElementById("enigOverrideGpg")
+   if (EnigGetPref("agentPath")) {
+      overrideGpg.checked = true;
+   }
+   else {
+      overrideGpg.checked = false;
+   }
+   enigActivateDependent(overrideGpg, "enigmail_agentPath enigmail_browsePath");
+   activateRulesButton(document.getElementById("enigmail_recipientsSelection"), "openRulesEditor");
+
    var testEmailElement = document.getElementById("enigmail_test_email");
    var userIdValue = EnigGetPref("userIdValue");
 
+   enigDetermineGpgPath();
+
    if (testEmailElement && userIdValue)
      testEmailElement.value = userIdValue;
 
 }
 
+function enigDetermineGpgPath() {
+  if (! gEnigmailSvc) {
+    try {
+      gEnigmailSvc = ENIG_C.classes[ENIG_ENIGMAIL_CONTRACTID].createInstance(ENIG_C.interfaces.nsIEnigmail);
+      if (! gEnigmailSvc.initialized) {
+        // attempt to initialize Enigmail
+        gEnigmailSvc.initialize(window, gEnigmailVersion, gPrefEnigmail);
+      }
+    } catch (ex) {}
+  }
+
+  if (gEnigmailSvc.initialized && gEnigmailSvc.agentPath) {
+    document.getElementById("enigmailGpgPath").setAttribute("value", EnigGetString("prefs.gpgFound", gEnigmailSvc.agentPath));
+  }
+  else {
+    document.getElementById("enigmailGpgPath").setAttribute("value", EnigGetString("prefs.gpgNotFound"));
+  }
+}
+
+function selectPrefTabPanel(panelName) {
+  var prefTabs=document.getElementById("prefTabs");
+  var selectTab=document.getElementById(panelName);
+  prefTabs.selectedTab = selectTab;
+}
+
 function resetPrefs() {
   DEBUG_LOG("pref-enigmail.js: resetPrefs\n");
 
@@ -124,15 +140,9 @@ function resetPrefs() {
 
   EnigSetPref("configuredVersion", gEnigmailVersion);
 
-  EnigDisplayRadioPref("usePGPMimeOption", EnigGetDefaultPref("usePGPMimeOption"),
-                      gUsePGPMimeOptionList);
-  EnigDisplayRadioPref("recipientsSelectionOption", EnigGetDefaultPref("recipientsSelectionOption"),
-                      gEnigRecipientsSelectionOptions);
-  EnigDisplayRadioPref("perRecipientRules", EnigGetPref("perRecipientRules"),
-                      gEnigPerRecipientRules);
-                      
+  EnigDisplayRadioPref("recipientsSelection", EnigGetPref("recipientsSelection"),
+                      gEnigRecipientsSelection);
 
-  gMimeHashElement.selectedIndex = EnigGetDefaultPref("mimeHashAlgorithm")-1;
 }
 
 function resetRememberedValues() {
@@ -146,7 +156,7 @@ function resetRememberedValues() {
              "warnOnRulesConflict",
              "warnClearPassphrase",
              "warnRefreshAll"];
-             
+
   for (var j=0; j<prefs.length; j++) {
     EnigSetPref(prefs[j], EnigGetDefaultPref(prefs[j]));
   }
@@ -156,25 +166,18 @@ function resetRememberedValues() {
 function prefOnAccept() {
 
   DEBUG_LOG("pref-enigmail.js: prefOnAccept\n");
-  
+
   var oldAgentPath = EnigGetPref("agentPath");
+
+  if (! document.getElementById("enigOverrideGpg").checked) {
+    document.getElementById("enigmail_agentPath").value = "";
+  }
   var newAgentPath = document.getElementById("enigmail_agentPath").value;
-  
+
   EnigDisplayPrefs(false, false, true);
 
-  EnigSetRadioPref("usePGPMimeOption", gUsePGPMimeOptionList);
-
-  EnigSetPref("mimeHashAlgorithm", gMimeHashElement.selectedIndex+1);
-
-  EnigSetRadioPref("recipientsSelectionOption", gEnigRecipientsSelectionOptions);
-
-  EnigSetRadioPref("perRecipientRules", gEnigPerRecipientRules);
-
-  if (gSendFlowedElement &&
-      (gSendFlowedElement.checked != gSendFlowedValue) ) {
-
-    gEnigPrefRoot.setBoolPref("mailnews.send_plaintext_flowed", (gSendFlowedElement.checked ? true : false));
-  }
+  //setRecipientsSelectionPref(document.getElementById("enigmail_recipientsSelection").value);
+  //EnigSetRadioPref("recipientsSelection", gEnigRecipientsSelection);
 
   if (gMimePartsElement &&
       (gMimePartsElement.checked != gMimePartsValue) ) {
@@ -206,10 +209,63 @@ function prefOnAccept() {
       GetEnigmailSvc();
     }
   }
-  
+
   return true;
 }
 
+function enigActivateDependent (obj, dependentIds) {
+  var idList = dependentIds.split(/ /);
+  var depId;
+
+  for (depId in idList) {
+    if (obj.checked) {
+      document.getElementById(idList[depId]).removeAttribute("disabled");
+    }
+    else {
+      document.getElementById(idList[depId]).setAttribute("disabled", "true");
+    }
+  }
+  return true;
+}
+
+function enigSwitchAdvancedMode(checkbox) {
+
+  var origPref = EnigGetPref("advancedUser");
+
+  if (checkbox.checked) {
+    EnigSetPref("advancedUser", true);
+  }
+  else {
+    EnigSetPref("advancedUser", false);
+  }
+
+  var prefTabBox  = document.getElementById("prefTabBox");
+  if (prefTabBox) {
+    // Thunderbird
+    EnigCollapseAdvanced(prefTabBox, "hidden", null);
+    EnigCollapseAdvanced(document.getElementById("enigPrefTabPanel"), "hidden", null);
+  }
+  else {
+    // Seamonkey
+    EnigCollapseAdvanced(document.getElementById("enigmailPrefsBox"), "hidden", null);
+  }
+  EnigSetPref("advancedUser", origPref);
+}
+
+function enigAlertAskNever () {
+  EnigAlert(EnigGetString("prefs.warnAskNever"));
+}
+
+function activateRulesButton(radioListObj, buttonId) {
+  switch (radioListObj.value) {
+  case "3":
+  case "4":
+    document.getElementById(buttonId).setAttribute("disabled", "true");
+    break;
+  default:
+    document.getElementById(buttonId).removeAttribute("disabled");
+  }
+}
 
 
 function EnigMimeTest() {
@@ -282,7 +338,7 @@ function EnigTest() {
     var statusFlagsObj = new Object();
     var errorMsgObj    = new Object();
 
-    var cipherText = enigmailSvc.encryptMessage(window, uiFlags, plainText,
+    var cipherText = enigmailSvc.encryptMessage(window, uiFlags, null, plainText,
                                                 "", toMailAddr,
                                                 nsIEnigmail.SEND_SIGNED,
                                                 exitCodeObj, statusFlagsObj,
@@ -296,14 +352,17 @@ function EnigTest() {
     var signatureObj   = new Object();
     var keyIdObj       = new Object();
     var userIdObj      = new Object();
-    var sigDetailsObj      = new Object();
+    var sigDetailsObj  = new Object();
+    var blockSeparationObj  = new Object();
 
-    var decryptedText = enigmailSvc.decryptMessage(window, 
+    var decryptedText = enigmailSvc.decryptMessage(window,
                                         uiFlags, cipherText,
                                         signatureObj, exitCodeObj,
                                         statusFlagsObj, keyIdObj, userIdObj,
                                         sigDetailsObj,
-                                        errorMsgObj);
+                                        errorMsgObj,
+                                        blockSeparationObj);
+
     CONSOLE_LOG("\n************************************************\n");
     CONSOLE_LOG("EnigTest: VERIFICATION\n");
     CONSOLE_LOG("EnigTest: decryptedText = "+decryptedText+"\n");
@@ -311,7 +370,7 @@ function EnigTest() {
     CONSOLE_LOG("EnigTest: signature = "+signatureObj.value+"\n");
     CONSOLE_LOG("************************************************\n");
 
-    cipherText = enigmailSvc.encryptMessage(window, uiFlags, plainText,
+    cipherText = enigmailSvc.encryptMessage(window, uiFlags, null, plainText,
                                                 "", toMailAddr,
                                                 nsIEnigmail.SEND_SIGNED|
                                                 nsIEnigmail.SEND_ENCRYPTED,
@@ -327,7 +386,8 @@ function EnigTest() {
                                         signatureObj, exitCodeObj,
                                         statusFlagsObj, keyIdObj, userIdObj,
                                         sigDetailsObj,
-                                        errorMsgObj);
+                                        errorMsgObj, blockSeparationObj);
+
     CONSOLE_LOG("\n************************************************\n");
     CONSOLE_LOG("EnigTest: DECRYPTION\n");
     CONSOLE_LOG("EnigTest: decryptedText = "+decryptedText+"\n");
@@ -361,30 +421,29 @@ function enigLocateGpg() {
 // Uninstallation stuff
 /////////////////////////
 
-function enigUninstall() 
+function enigUninstall()
 {
   if (!EnigConfirm(EnigGetString("uninstallConfirm"))) {
     return;
   }
-  
+
   try {
     var uninst=new enigUninstaller();
     uninst.uninstallPackage();
     EnigAlert(EnigGetString("uninstallSuccess"));
-    EnigShowHeadersAll(false);
     window.close();
   }
   catch (ex) {
     EnigAlert(EnigGetString("uninstallFail"));
   }
-  
-}  
+
+}
 
 // The part below is taken from jslib (http://jslib.mozdev.org)
 // CONSTRUCTOR
-function enigUninstaller() 
+function enigUninstaller()
 {
-  
+
   this.mNames = ["enigmail", "enigmime"];
 
   this.gRDF = enigGetService("@mozilla.org/rdf/rdf-service;1", "nsIRDFService");
@@ -411,31 +470,31 @@ enigUninstaller.prototype =
   packageDisplayName      : "",
 
 
-  finish : function () 
+  finish : function ()
   {
     // do nothing
   },
-  
-  generateUninstallInfo : function () 
+
+  generateUninstallInfo : function ()
   {
     if (!this.mUninstallInfoGenerated){
       this.mUninstallInfoGenerated = true;
-  
+
       this.filesToDelete = [];
       this.filesToDeleteHash = {};
       this.overlaysToDelete = [];
       this.baseURIs = {};
-  
+
       this.doUninstall(false);
     }
   },
-  
-  uninstallPackage : function () 
+
+  uninstallPackage : function ()
   {
     this.generateUninstallInfo();
     this.doUninstall(true);
   },
-  
+
   /**
    * Iterates over the items in an RDF Container
    */
@@ -446,29 +505,29 @@ enigUninstaller.prototype =
       container.Init(ds, resource);
     }
     catch (ex){ return; }
-  
+
     var elements = container.GetElements();
     while (elements.hasMoreElements()){
       var element = elements.getNext();
       callback(resource, element, this);
     }
   },
-  
+
   /**
    * Get all of the currently installed packages. This function is not currently used.
    */
   getAllPackagesInfo : function(chromeDS)
   {
     var allPackages = {};
-  
+
     var handlePackages = function(container, packres, uninstallObj)
     {
       var childPred = uninstallObj.gRDF.GetResource(uninstallObj.CHROME_NS + "name")
       var childName = chromeDS.GetTarget(packres, childPred, true);
-  
+
       var displayPred = uninstallObj.gRDF.GetResource(uninstallObj.CHROME_NS + "displayName")
       var displayName = chromeDS.GetTarget(packres, displayPred, true);
-  
+
       if (childName instanceof ENIG_C.interfaces.nsIRDFLiteral){
         if (displayName instanceof ENIG_C.interfaces.nsIRDFLiteral){
           displayName = displayName.Value;
@@ -479,11 +538,11 @@ enigUninstaller.prototype =
         allPackages[childName.Value] = displayName;
       }
     }
-  
+
     var rootseq = this.gRDF.GetResource("urn:mozilla:package:root");
     this.iterateContainer(chromeDS, rootseq, handlePackages);
   },
-  
+
   /**
    * Do the uninstallation. This function will be called twice. Once to generate
    * the list of files and overlays to delete, and the second to do the deletions.
@@ -491,64 +550,64 @@ enigUninstaller.prototype =
   doUninstall : function(makeChanges)
   {
     var ioService = enigGetService("@mozilla.org/network/io-service;1", "nsIIOService");
-  
+
     // scan through chrome.rdf and find all references to the package and remove them.
     var appChromeDir = this.gDirService.get("AChrom", ENIG_C.interfaces.nsIFile);
     var chromeRdfFile = appChromeDir.clone();
     chromeRdfFile.append("chrome.rdf");
     var chromeUrl = ioService.newFileURI(chromeRdfFile).spec;
     var appChromeDS = this.gRDF.GetDataSourceBlocking(chromeUrl);
-  
+
     for (var pt = 0; pt < this.mNames.length; pt++){
       this.handleChromeRDF(this.mNames[pt], appChromeDir, appChromeDS, makeChanges);
     }
-  
+
     // scan through chrome.rdf and find all references to the package and remove them.
     var userChromeDir = this.gDirService.get("UChrm", ENIG_C.interfaces.nsIFile);
     chromeRdfFile = userChromeDir.clone();
     chromeRdfFile.append("chrome.rdf");
     chromeUrl = ioService.newFileURI(chromeRdfFile).spec;
     var userChromeDS = this.gRDF.GetDataSourceBlocking(chromeUrl);
-  
+
     for (pt = 0; pt < this.mNames.length; pt++){
       this.handleChromeRDF(this.mNames[pt], userChromeDir, userChromeDS, makeChanges);
     }
-  
+
     if (makeChanges){
       if (appChromeDS instanceof ENIG_C.interfaces.nsIRDFRemoteDataSource)
           appChromeDS.Flush();
       if (userChromeDS instanceof ENIG_C.interfaces.nsIRDFRemoteDataSource)
           userChromeDS.Flush();
-  
+
       for (t=0; t<this.overlaysToDelete.length; t++){
         this.removeOverlay(this.overlaysToDelete[t]);
       }
-  
+
       this.removeFromInstalledChrome(appChromeDir);
-  
+
       var uninstallObj = this;
       var callback = function() {  uninstallObj.doNextUninstallStep(uninstallObj,0); }
       setTimeout(callback,50);
     }
   },
-  
+
   doNextUninstallStep : function(uninstallObj,step)
   {
-  
+
     if (step >= uninstallObj.filesToDelete.length){
       return;
     }
-  
+
     // ignore errors since it doesn't matter if a file could not be found, and
     // non-empty directories should not be deleted.
     try {
       var file = uninstallObj.filesToDelete[step];
       var path = file.path;
-  
+
       DEBUG_LOG("pref-enigmail.js: Uninstalling " + file.leafName+": ");
-  
+
       var ext = path.substring(path.lastIndexOf(".")+1, path.length);
-      // close the jar filehandle so we can unlock it and delete it on 
+      // close the jar filehandle so we can unlock it and delete it on
       // OS's like Windows that like to lock their open files
       if (ext == "jar") {
         var IOService = enigGetService("@mozilla.org/network/io-service;1", "nsIIOService");
@@ -566,11 +625,11 @@ enigUninstaller.prototype =
       catch (ex) {}
     }
     catch (ex){ DEBUG_LOG(ex); }
-  
+
     var callback = function() {  uninstallObj.doNextUninstallStep(uninstallObj,step + 1); }
     setTimeout(callback,50);
   },
-  
+
   /**
    * Gather information about the package from a chrome.rdf file and remove it.
    */
@@ -579,13 +638,13 @@ enigUninstaller.prototype =
     // remove package from content
     var rootseq = this.gRDF.GetResource("urn:mozilla:package:root");
     var packres = this.gRDF.GetResource("urn:mozilla:package:" + packagename);
-  
+
     if (makeChanges){
       this.removeFromChrome(chromeDS, rootseq, packres);
     }
     else {
       this.generateUninstallData(chromeDS, rootseq, packres, chromeDir);
-  
+
       if (!this.packageDisplayName){
         var displayNamePred = this.gRDF.GetResource(this.CHROME_NS + "displayName")
         var displayName = chromeDS.GetTarget(packres, displayNamePred, true);
@@ -597,38 +656,38 @@ enigUninstaller.prototype =
         }
       }
     }
-  
+
     // remove package from skin
     var provider = "skin";
-  
+
     var handleSkinLocaleList = function(container, skinLocale, uninstallObj)
     {
       var rootseq = chromeDS.GetTarget(skinLocale,
                       uninstallObj.gRDF.GetResource(uninstallObj.CHROME_NS + "packages"),true);
       rootseq.QueryInterface(ENIG_C.interfaces.nsIRDFResource);
-  
+
       var skinLocaleName = chromeDS.GetTarget(skinLocale,
             uninstallObj.gRDF.GetResource(uninstallObj.CHROME_NS + "name"),true);
-  
+
       if (skinLocaleName instanceof ENIG_C.interfaces.nsIRDFLiteral){
         var skinLocaleRes = uninstallObj.gRDF.GetResource("urn:mozilla:" + provider + ":" +
                               skinLocaleName.Value + ":" + packagename);
-  
+
         if (makeChanges) uninstallObj.removeFromChrome(chromeDS, rootseq, skinLocaleRes);
         else uninstallObj.generateUninstallData(chromeDS, rootseq, skinLocaleRes, chromeDir);
       }
     };
-  
+
     var packreslist = this.gRDF.GetResource("urn:mozilla:skin:root");
     this.iterateContainer(chromeDS, packreslist, handleSkinLocaleList);
-  
+
     // remove package from locale
     provider = "locale";
-  
+
     packreslist = this.gRDF.GetResource("urn:mozilla:locale:root");
     this.iterateContainer(chromeDS, packreslist, handleSkinLocaleList);
   },
-  
+
   /**
    * Perform an uninstallation given a contents.rdf datasource.
    *   aChromeDS   - chrome.rdf datasource
@@ -645,15 +704,15 @@ enigUninstaller.prototype =
         ds = this.gRDF.GetDataSourceBlocking(baseUrl.Value + "contents.rdf");
       }
       catch (ex){ DEBUG_LOG(ex); return; }
-  
+
       this.markJarForDeletion(baseUrl.Value);
-  
+
       this.generateFilesToDelete(ds, packres);
       this.generateOverlaysToDelete(ds, chromeDir, "overlays");
       this.generateOverlaysToDelete(ds, chromeDir, "stylesheets");
     }
   },
-  
+
   /**
    * Generate the files to delete, which are listed in the uninstallInfo section
    * of the contents.rdf
@@ -666,7 +725,7 @@ enigUninstaller.prototype =
       this.iterateContainer(aDS, uninstallInfo, this.makeFileForDeletion);
     }
   },
-  
+
   /**
    * Mark a file for deletion.
    */
@@ -674,7 +733,7 @@ enigUninstaller.prototype =
   {
     if (!(filename instanceof ENIG_C.interfaces.nsIRDFLiteral)) return;
     filename = filename.Value;
-  
+
     var filekey;
     var colonIdx = filename.indexOf(":");
     if (colonIdx >= 0){
@@ -684,45 +743,45 @@ enigUninstaller.prototype =
     else {
       filekey = "CurProcD";
     }
-  
+
     var file;
     try {
        file = uninstallObj.gDirService.get(filekey, ENIG_C.interfaces.nsIFile);
     } catch (ex) { return; }
-  
+
     var fileparts = filename.split("/");
     for (var t=0; t<fileparts.length; t++){
       file.append(fileparts[t]);
     }
-  
+
     if (!uninstallObj.filesToDeleteHash[file.path]){
       uninstallObj.filesToDeleteHash[file.path] = file;
       uninstallObj.filesToDelete.push(file);
     }
   },
-  
+
   /**
    * Given a baseURI reference, determine the JAR file to delete.
    */
   markJarForDeletion : function(url)
   {
     this.baseURIs[url] = url;
-  
+
     if (url.indexOf("jar:")) return;
-  
+
     var jarfile;
-  
+
     url = url.substring(4);
-  
+
     var expos = url.indexOf("!");
     if (expos > 0){
       url = url.substring(0,expos);
-  
+
       if (url.indexOf("resource:/") == 0){
         url = url.substring(10);
-  
+
         jarfile = this.gDirService.get("CurProcD", ENIG_C.interfaces.nsIFile);
-  
+
         var fileparts = url.split("/");
         for (var t=0; t<fileparts.length; t++){
           jarfile.append(fileparts[t]);
@@ -736,13 +795,13 @@ enigUninstaller.prototype =
         }
       }
     }
-  
+
     if (!this.filesToDeleteHash[jarfile.path]){
       this.filesToDeleteHash[jarfile.path] = jarfile;
       this.filesToDelete.push(jarfile);
     }
   },
-  
+
   /**
    * Generate the list of overlays referenced in a contents.rdf file.
    */
@@ -759,16 +818,16 @@ enigUninstaller.prototype =
             type: overlayType });
       }
     }
-  
+
     var iterateOverlaids = function(container, overlaidFile, uninstallObj)
     {
       uninstallObj.iterateContainer(aDS, overlaidFile, iterateOverlays);
     }
-  
+
     var oroot = this.gRDF.GetResource("urn:mozilla:" + overlayType);
     this.iterateContainer(aDS, oroot, iterateOverlaids);
   },
-  
+
   /**
    * Remove an overlay from the overlayinfo.
    */
@@ -776,17 +835,17 @@ enigUninstaller.prototype =
   {
     DEBUG_LOG("pref-enigmail: removeOverlay\n");
     var overlayItems = this.splitURL(overlay.overlaidFile.Value);
-  
+
     var overlayRdfFile = overlay.chromeDir.clone();
     overlayRdfFile.append("overlayinfo");
     overlayRdfFile.append(overlayItems.packagename);
     overlayRdfFile.append(overlayItems.provider);
     overlayRdfFile.append(overlay.type + ".rdf");
-  
+
     var ioService = enigGetService("@mozilla.org/network/io-service;1", "nsIIOService");
     var overlayRdfUrl = ioService.newFileURI(overlayRdfFile).spec;
     var dsource = this.gRDF.GetDataSourceBlocking(overlayRdfUrl);
-  
+
     try {
       DEBUG_LOG("pref-enigmail: removeOverlay: Uncontain Overlay " + this.RDFGetValue(overlay.overlayFile) +
            " from " + this.RDFGetValue(overlay.overlaidFile) + "\n");
@@ -795,11 +854,11 @@ enigUninstaller.prototype =
       container.RemoveElement(overlay.overlayFile, true);
     }
     catch (ex) { DEBUG_LOG(ex); }
-  
+
     if (dsource instanceof ENIG_C.interfaces.nsIRDFRemoteDataSource)
       dsource.Flush();
   },
-  
+
   /**
    * split a chrome URL into component parts.
    *
@@ -808,25 +867,25 @@ enigUninstaller.prototype =
   splitURL : function(url)
   {
     if (url.indexOf("chrome://")) return null;
-  
+
     var packagename = url.substring(9);
     var slashidx = packagename.indexOf("/");
     if (slashidx == -1) return null;
-  
+
     var provider = packagename.substring(slashidx + 1);
     packagename = packagename.substring(0,slashidx);
-   
+
     slashidx = provider.indexOf("/");
     if (slashidx >= 0){
       provider = provider.substring(0,slashidx);
     }
-  
+
     return {
       packagename: packagename,
       provider: provider
     };
   },
-  
+
   /**
    * Useful debugging function to convert an nsIRDFNode into a string.
    */
@@ -835,15 +894,15 @@ enigUninstaller.prototype =
     return ((node instanceof ENIG_C.interfaces.nsIRDFResource) ? node.Value :
             ((node instanceof ENIG_C.interfaces.nsIRDFLiteral) ? node.Value : ""));
   },
-  
+
   /**
    * Remove references to a package from chrome.rdf.
    */
-  removeFromChrome : function (dsource, rootseq, packres) 
+  removeFromChrome : function (dsource, rootseq, packres)
   {
     DEBUG_LOG("pref-enigmail: removeFromChrome\n");
     var packresnode = packres.QueryInterface(ENIG_C.interfaces.nsIRDFNode);
-  
+
     try {
       DEBUG_LOG("pref-enigmail: removeFromChrome: Uncontain " + packres.Value + " from " +
                  rootseq.Value + "\n");
@@ -852,19 +911,19 @@ enigUninstaller.prototype =
       container.RemoveElement(packresnode, true);
     }
     catch (ex) { DEBUG_LOG(ex); }
-  
+
     var arcs = dsource.ArcLabelsOut(packres);
-  
+
     while(arcs.hasMoreElements()) {
       var arc = arcs.getNext();
-      
+
       var prop = arc.QueryInterface(ENIG_C.interfaces.nsIRDFResource);
-  
+
       var targets = dsource.GetTargets(packres, prop, true);
-  
+
       while (targets.hasMoreElements()) {
         var target = targets.getNext();
-  
+
         var targetNode = target.QueryInterface(ENIG_C.interfaces.nsIRDFNode);
         DEBUG_LOG("pref-enigmail: removeFromChrome: Unassert [" + packres.Value + " , " +
               prop.Value + " , " + this.RDFGetValue(target) + "]\n");
@@ -872,7 +931,7 @@ enigUninstaller.prototype =
       }
     }
   },
-  
+
   removeFromInstalledChrome : function(chromeDir)
   {
     DEBUG_LOG("pref-enigmail: removeFromInstalledChrome\n");
@@ -880,16 +939,16 @@ enigUninstaller.prototype =
     chromeDir.append("installed-chrome.txt");
     var ifile = new File(chromeDir.path);
     ifile.open("r");
-  
+
     var changeNeeded = false;
-  
+
     try {
       var content = "";
-  
+
       while (!ifile.EOF){
         var found = false;
         var ln = ifile.readline();
-  
+
         for (uri in this.baseURIs){
           var idx = ln.indexOf(uri);
           if ((idx > 0) && (idx == ln.length - uri.length)){
@@ -904,7 +963,7 @@ enigUninstaller.prototype =
     finally {
       ifile.close();
     }
-  
+
     if (changeNeeded){
       ifile.open("w",0664);
       try {
